==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translation>Bogen en cirkels</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translation>in lijn segmenten (vaste lengte)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translation>in lijn segmenten (vaste hoek)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translation>Ovaalen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translation>in polylijn met boogsegmenten</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translation>in polylijn met lijnsegmenten</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translation>Splines</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translation>Bematingen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translation>in lijnen, opvullingen en teksten</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translation>Arceringen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translation>in lijnen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translation>Blokken</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translation>in objecten</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>Modificeren</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>Exploderen</translation>
    </message>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translation>&amp;Exploderen</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+133"/>
        <source>Spline segments:</source>
        <translation>Spline segmenten:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>Ellipse segmenten (per volledige ellips):</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Spline approximation tolerance:</source>
        <translation>Spline tolerantie:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translation>Bogen en cirkels</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translation>in lijn segmenten (vaste lengte)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translation>in lijn segmenten (vaste hoek)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translation>Ovaalen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translation>in polylijn met boogsegmenten</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translation>in polylijn met lijnsegmenten</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translation>Splines</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translation>Bematingen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translation>in lijnen, opvullingen en teksten</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translation>Arceringen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translation>in lijnen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translation>Blokken</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translation>in objecten</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>Modificeren</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>Exploderen</translation>
    </message>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translation>&amp;Exploderen</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+197"/>
        <source>Explode text glyphs to polylines</source>
        <translation>Tekstcontouren exploderen in polylines</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Spline segments:</source>
        <translation>Spline segmenten:</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>Ellipse segmenten (per volledige ellips):</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Explode splines to polylines with line segments</source>
        <translation>Splines exploderen in polylijnen met lijnstukken</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Explode multiline texts into multiple simple text blocks</source>
        <translation>Teksten met meerdere regels in meerdere eenvoudige tekstblokken opbreken</translation>
    </message>
    <message>
        <location line="-31"/>
        <source>Spline approximation tolerance:</source>
        <translation>Spline tolerantie:</translation>
    </message>
</context>
</TS>
